gRbase-generics: Compile and propagate functions
Description
compile and propagate are generic
functions which invoke particular methods which depend on the
class of the first argument
Usage
fit(object, ...)compile(object, ...)
propagate(object, ...)
stepwise(object, ...)
Arguments
…
Additional arguments which depends on the class of the object
Value
The value returned depends on the class of the first argument.
References
H<U+00F8>jsgaard, S<U+00F8>ren; Edwards, David; Lauritzen, Steffen (2012):
Graphical Models with R, Springer